# Connotati

[![License: GPL v3+](https://img.shields.io/badge/license-GPL%20v3%2B-blue.svg)](http://www.gnu.org/licenses/gpl-3.0)

![an example run](https://raw.githubusercontent.com/tallero/connotati/master/screenshots/connotati-in-action.gif)

*Connotati* (Italian for *salient characteristics and markings*) is a small stupid `python 3.x` script for GNU/Linux or other POSIX systems supported by GTK+ (and supported by `xdotool` and `xprop` for windows pattern matching feature) to start GTK+ applications with given theme and variant.

## Installation

*Connotati* is available through the [Python Package Index (PyPI)](https://pypi.org/). Pip is already installed if you are using Python 3 >=3.4 downloaded from [python.org](https://python.org); if you're using a GNU/Linux distribution, you can find how to install it on this [page](https://packaging.python.org/guides/installing-using-linux-tools/#installing-pip-setuptools-wheel-with-linux-package-managers).
After setting up pip, you can install *connotati* by simply typing in your terminal

    pip3 install connotati

## Usage

The script source code is heavily documented; you can access the command line help with

    connotati --help

## About

This program is licensed under [GNU General Public License v3 or later](https://www.gnu.org/licenses/gpl-3.0.en.html) by [Pellegrino Prevete](http://prevete.ml). If you find this program useful, consider offering me a [beer](https://patreon.com/tallero), a new [computer](https://patreon.com/tallero) or a part time remote [job](mailto:pellegrinoprevete@gmail.com) to help me pay the bills.    
